"use strict";
const common_vendor = require("../../../common/vendor.js");
const common_js_net_shop = require("../../../common/js/net/shop.js");
const common_js_net_mainUrl = require("../../../common/js/net/mainUrl.js");
const common_js_cache_storage = require("../../../common/js/cache/storage.js");
const common_js_util = require("../../../common/js/util.js");
const _sfc_main = {
  setup() {
  },
  data() {
    return {
      curStartDate: common_js_util.currentDate(),
      personType: [{
        dataName: "自然人",
        dataId: "1"
      }, {
        dataName: "法人",
        dataId: "2"
      }, {
        dataName: "非法人组织或其他",
        dataId: "3"
      }],
      selPersonType: null,
      creType: [],
      rightType: [],
      areaList: [],
      //省
      cityList: [],
      //市
      rightName: "",
      //软著名称
      orgName: "",
      //著作权人姓名
      orgPhone: "",
      //联系电话
      cardNumber: "",
      //证件号码
      selRightType: [],
      //选中分类
      rightPrice: "",
      //售价
      rightStopDate: "",
      //停止日期
      selCreType: null,
      //选中证件类型
      showArea: false,
      prevValue: [0, 0],
      // 用于存储上一次的值
      selArea: null,
      selCity: null,
      msgHint: "",
      msgType: "info",
      msgShow: false,
      files: [],
      showType: false,
      goodsId: "",
      goods: null,
      imageStyles: {
        width: 200,
        height: 240,
        border: {
          color: "#e5e5e5",
          width: 1,
          style: "solid",
          radius: "2px"
        }
      }
    };
  },
  onLoad(options) {
    common_vendor.index.setNavigationBarTitle({
      title: "发布商品"
    });
    common_vendor.index.setNavigationBarColor({
      frontColor: "#000000",
      backgroundColor: "#FFFFFF",
      animation: {
        duration: 500,
        timingFunc: "easeIn"
      }
    });
    this.selPersonType = this.personType[0];
    var id = options.id;
    if (id && id != "") {
      this.goodsId = id;
      this.doGetGoodsDetail();
    } else {
      this.getDic();
    }
  },
  methods: {
    //获取商品详情
    doGetGoodsDetail: function() {
      common_vendor.index.showLoading({
        title: "加载中..."
      });
      var that = this;
      common_js_net_shop.Shop.doGetGoodsDetail(that.goodsId).then(function(res) {
        common_vendor.index.hideLoading();
        var tempFile = [{
          fileId: res.goodsLocalPhoto,
          fileName: "image",
          fileSize: 0,
          fileUrl: common_js_net_mainUrl.sImgPrefix + res.goodsLocalPhoto,
          url: common_js_net_mainUrl.sImgPrefix + res.goodsLocalPhoto
        }];
        that.rightName = res.goodsName;
        that.rightPrice = res.goodsPrice;
        that.rightStopDate = res.goodsLastTime;
        that.orgName = res.goodsLeader;
        that.orgPhone = res.goodsLeaderPhone;
        that.cardNumber = res.goodsLeaderIdcard;
        that.files = tempFile;
        that.goods = res;
        that.getDic();
      }).catch(function(err) {
        common_vendor.index.hideLoading();
        that.msgHint = err.msg ? err.msg : "网络错误,请稍后重试";
        that.msgType = "error";
        that.$refs.msg.open();
        setTimeout(function() {
          common_vendor.index.navigateBack();
        }, 1500);
      });
    },
    inputRightName: function(e) {
      this.rightName = e.detail.value;
    },
    doClearRightName: function() {
      this.rightName = "";
    },
    inputRightPrice: function(e) {
      this.rightPrice = e.detail.value;
    },
    doClearPrice: function() {
      this.rightPrice = 0;
    },
    inputOrgName: function(e) {
      this.orgName = e.detail.value;
    },
    inputCardNumber: function(e) {
      this.cardNumber = e.detail.value;
    },
    //著作权人类别
    bindChangePersonType: function(e) {
      this.selPersonType = this.personType[e.detail.value];
    },
    clearPersonType: function() {
      this.selPersonType = null;
    },
    //证件类型
    bindChangeCreType: function(e) {
      this.selCreType = this.creType[e.detail.value];
    },
    clearCreType: function() {
      this.selCreType = null;
    },
    //选择软著分类
    onShowRightType: function() {
      this.$refs.typeDialog.open();
    },
    //选择软著分类
    bindChangeRightType: function(e) {
      const currentItem = e.currentTarget.dataset.value;
      const dataId = currentItem.dataId;
      const selectedIndex = this.selRightType.findIndex((item) => item.dataId === dataId);
      const targetItem = this.rightType.find((item) => item.dataId === dataId);
      if (targetItem) {
        targetItem.checked = !targetItem.checked;
      }
      if (selectedIndex !== -1) {
        this.selRightType.splice(selectedIndex, 1);
      } else {
        this.selRightType.push(targetItem);
      }
    },
    clearRightType: function() {
      this.rightType.forEach(function(item) {
        item.checked = false;
      });
      this.selRightType = [];
      this.rightType = this.rightType;
    },
    confirmSelRightType: function() {
      this.showType = false;
    },
    //显示日期选择
    bindDateChange: function(e) {
      this.rightStopDate = e.detail.value;
    },
    clearTime: function() {
      this.rightStopDate = "";
    },
    //删除图片
    delImgs(e) {
      common_vendor.index.__f__("log", "at pages/shop/publishGoods/publishGoods.vue:390", "删除凭证", e);
      this.files.splice(e.index, 1);
    },
    //上传图片
    async uploadImgToNet(e) {
      common_vendor.index.showLoading({
        title: "上传中..."
      });
      const tempFilePaths = e.tempFilePaths;
      const token = common_js_cache_storage.get("token");
      const header = token ? {
        Auth: `Bearer ${token}`
      } : {};
      const that = this;
      try {
        const results = [];
        for (let i = 0; i < tempFilePaths.length; i++) {
          const filePath = tempFilePaths[i];
          const result = await new Promise((resolve, reject) => {
            common_vendor.index.uploadFile({
              url: common_js_net_mainUrl.upShopImgUrl,
              header,
              filePath,
              name: "image",
              success(res) {
                if (res.statusCode === 200) {
                  let data = res.data;
                  if (typeof data === "string") {
                    data = JSON.parse(data);
                  }
                  resolve(data.data);
                } else {
                  reject(new Error("上传失败，状态码非200"));
                }
              },
              fail(err) {
                reject(err);
              }
            });
          });
          result.url = common_js_net_mainUrl.sImgPrefix + result.fileId;
          result.name = result.fileName;
          let lastDot = result.fileName.lastIndexOf(".");
          result.extname = result.fileName.substring(lastDot + 1);
          results.push(result);
        }
        that.files = that.files.concat(results);
        common_vendor.index.hideLoading();
      } catch (error) {
        common_vendor.index.hideLoading();
        that.msgHint = "凭证上传失败,请稍后重试";
        that.msgType = "error";
        that.$refs.msg.open();
        that.$refs.imgPicker.clearFiles();
        common_vendor.index.__f__("error", "at pages/shop/publishGoods/publishGoods.vue:451", "上传错误:", error);
      }
    },
    //显示省市选择
    onShowArea: function() {
      this.$refs.areaDialog.open();
    },
    //关闭省市选择
    closeDialog() {
      this.$refs.areaDialog.close();
      this.$refs.typeDialog.close();
    },
    clearArea: function() {
      this.selArea = null;
      this.selCity = null;
    },
    confirmSelArea: function() {
      this.showArea = false;
    },
    inputOrgPhone: function(e) {
      this.orgPhone = e.detail.value;
    },
    doClearPhone: function() {
      this.orgPhone = "";
    },
    //获取字典
    getDic: function() {
      var that = this;
      var cre = common_js_net_shop.Shop.doGetGoodsDic("0b00884a-f7a2-425f-93e5-599fbaad4bde");
      var right = common_js_net_shop.Shop.doGetGoodsDic("ce3ded65-68ed-4f42-89da-de1b813b8f7e");
      var area = common_js_net_shop.Shop.doGetAreaList("0");
      var list = [cre, right, area];
      Promise.all(list).then(function(res) {
        if (res) {
          that.rightType = res[0];
          that.creType = res[1];
          that.areaList = res[2];
          that.rightType.forEach(function(item) {
            item.checked = false;
          });
          if (that.goodsId != "") {
            that.rightType.forEach(function(item) {
              if (that.goods.goodsType.indexOf(item.dataId) != -1) {
                item.checked = true;
                that.selRightType.push(item);
              }
            });
            var tempPersonType;
            that.personType.forEach(function(item) {
              if (that.goods.goodsLeaderType == item.dataId) {
                tempPersonType = item;
              }
            });
            var tempCreType;
            that.creType.forEach(function(item) {
              if (that.goods.goodsLeaderIdcardType == item.dataId) {
                tempCreType = item;
              }
            });
            var tempSelArea = null;
            var tempIndex = 0;
            that.areaList.forEach(function(item, index) {
              if (that.goods.goodsLeaderCity1 == item.areaId) {
                tempSelArea = item;
                tempIndex = index;
              }
            });
            that.rightType = that.rightType;
            that.selRightType = that.selRightType;
            that.selPersonType = tempPersonType;
            that.selCreType = tempCreType;
            that.selArea = tempSelArea;
            that.prevValue[0] = tempIndex;
            that.doGetArea(that.selArea.areaId, false);
          } else {
            that.selCreType = that.creType[0];
            that.selArea = that.areaList[0];
            that.rightType = that.rightType;
            that.doGetArea(that.selArea.areaId, false);
          }
        }
      }).catch(function(err) {
        that.msgHint = err.msg ? err.msg : "数据加载错误,请稍后重试";
        that.msgType = "error";
        that.$refs.msg.open();
        setTimeout(function() {
          common_vendor.index.navigateBack();
        }, 1500);
      });
    },
    //获取区域
    doGetArea: function(pId, isChange) {
      common_vendor.index.showLoading({
        title: "加载中..."
      });
      var that = this;
      common_js_net_shop.Shop.doGetAreaList(pId).then(function(res) {
        common_vendor.index.hideLoading();
        if (res) {
          that.cityList = res;
          if (that.goodsId != "") {
            if (isChange) {
              that.selCity = res[0];
              that.prevValue[1] = 0;
            } else {
              var tempCity = null;
              var tempIndex = 0;
              that.cityList.forEach(function(item, index) {
                if (that.goods.goodsLeaderCity2 == item.areaId) {
                  tempCity = item;
                  tempIndex = index;
                }
              });
              that.selCity = tempCity;
              that.prevValue[1] = tempIndex;
            }
          } else {
            that.selCity = res[0];
          }
        }
      }).catch(function(err) {
        common_vendor.index.hideLoading();
        that.msgHint = err.msg ? err.msg : "数据加载错误,请稍后重试";
        that.msgType = "error";
        that.$refs.msg.open();
      });
    },
    //选中省市
    confirmSelType() {
      this.$refs.areaDialog.close();
      this.$refs.typeDialog.close();
    },
    //选中省市
    areaChange: function(e) {
      common_vendor.index.__f__("log", "at pages/shop/publishGoods/publishGoods.vue:593", e);
      common_vendor.index.__f__("log", "at pages/shop/publishGoods/publishGoods.vue:594", this.prevValue);
      const _self = this;
      const currentValue = e.detail.value;
      const prevValue = _self.prevValue;
      _self.prevValue = currentValue;
      for (let i = 0; i < currentValue.length; i++) {
        if (currentValue[i] !== prevValue[i]) {
          if (i === 0) {
            const area = _self.areaList[currentValue[0]];
            _self.selArea = area;
            _self.doGetArea(area.areaId, true);
          } else {
            const city = _self.cityList[currentValue[1]];
            _self.selCity = city;
          }
          break;
        }
      }
    },
    //发布新商品
    doConfirmPublish: function() {
      var isLegal = this.checkParams();
      if (isLegal) {
        var that = this;
        var data = that.buildParams();
        common_vendor.index.showLoading({
          title: "保存中..."
        });
        common_js_net_shop.Shop.doSaveGoods(data).then(function(res) {
          common_vendor.index.hideLoading();
          that.msgType = "success";
          that.msgHint = "保存成功";
          that.$refs.msg.open();
          setTimeout(function() {
            that.backPageRefresh();
          }, 1500);
        }).catch(function(err) {
          common_vendor.index.hideLoading();
          that.msgType = "error";
          that.msgHint = err.msg ? err.msg : "网络错误,请稍后重试";
          that.$refs.msg.open();
        });
      }
    },
    //修改新商品
    doConfirmUpdate: function() {
      var isLegal = this.checkParams();
      if (isLegal) {
        var that = this;
        var data = that.buildParams();
        common_vendor.index.showLoading({
          title: "保存中..."
        });
        common_js_net_shop.Shop.doUpdateGoods(that.goodsId, data).then(function(res) {
          common_vendor.index.hideLoading();
          that.msgType = "success";
          that.msgHint = "修改成功";
          that.$refs.msg.open();
          setTimeout(function() {
            that.backPageRefresh();
          }, 1500);
        }).catch(function(err) {
          common_vendor.index.hideLoading();
          that.msgType = "error";
          that.msgHint = err.msg ? err.msg : "网络错误,请稍后重试";
          that.$refs.msg.open();
        });
      }
    },
    //保存商品
    doSave: function() {
      if (this.goodsId != "") {
        this.doConfirmUpdate();
      } else {
        this.doConfirmPublish();
      }
    },
    //校验参数
    checkParams: function() {
      const rules = [
        {
          field: "rightName",
          message: "请输入软著名称",
          validator: (v) => typeof v === "string" && v.trim().length > 0
        },
        {
          field: "selRightType",
          message: "请选择软著分类",
          validator: (v) => v !== null && v.length > 0
        },
        {
          field: "rightPrice",
          message: "请输入软著售价",
          validator: (v) => typeof v === "string" || typeof v === "number" ? ("" + v).trim().length > 0 : false
        },
        {
          field: "rightStopDate",
          message: "请选择截止售卖日期",
          validator: (v) => typeof v === "string" && v.trim().length > 0
        },
        {
          field: "files",
          message: "请上传软著图片",
          validator: (v) => v && v.length > 0
        },
        {
          field: "selPersonType",
          message: "请选择著作权人类别",
          validator: (v) => v !== null
        },
        {
          field: "orgName",
          message: "请输入姓名或机构名称",
          validator: (v) => typeof v === "string" && v.trim().length > 0
        },
        {
          field: ["selArea", "selCity"],
          message: "请选择所在省市",
          validator: (_, data) => data.selArea !== null && data.selCity !== null
        },
        {
          field: "orgPhone",
          message: "请输入合法的联系电话",
          validator: (v) => {
            const isValidPhone = (phone) => /^1[3-9]\d{9}$/.test(phone);
            return typeof v === "string" && v.trim().length > 0 && isValidPhone(v.trim());
          }
        },
        {
          field: "selCreType",
          message: "请选择证件类型",
          validator: (v) => v !== null
        },
        {
          field: "cardNumber",
          message: "请输入证件号码",
          validator: (v) => typeof v === "string" && v.trim().length > 0
        }
      ];
      for (let i = 0; i < rules.length; i++) {
        const rule = rules[i];
        let isValid;
        if (Array.isArray(rule.field)) {
          isValid = rule.validator(null, this.$data);
        } else {
          const value = this.$data[rule.field];
          isValid = rule.validator(value, this.$data);
        }
        if (!isValid) {
          this.msgHint = rule.message;
          this.msgType = "error";
          this.$refs.msg.open();
          return false;
        }
      }
      return true;
    },
    buildParams: function() {
      var typeIds = this.selRightType.map(function(item) {
        return item.dataId;
      }).join(",");
      var data = {
        goodsLastTime: this.rightStopDate,
        goodsLeader: this.orgName,
        goodsLeaderCity1: this.selArea.areaId,
        goodsLeaderCity2: this.selCity.areaId,
        goodsLeaderIdcard: this.cardNumber,
        goodsLeaderIdcardType: this.selCreType.dataId,
        goodsLeaderPhone: this.orgPhone,
        goodsLeaderType: this.selPersonType.dataId,
        goodsName: this.rightName,
        goodsLocalPhoto: this.files[0].fileId,
        goodsPrice: this.rightPrice,
        goodsType: typeIds
      };
      return data;
    },
    backPageRefresh: function() {
      var pages = getCurrentPages();
      var beforePage = pages[pages.length - 2];
      beforePage.$vm.needRefresh = true;
      common_vendor.index.navigateBack();
    }
  }
};
if (!Array) {
  const _easycom_uni_file_picker2 = common_vendor.resolveComponent("uni-file-picker");
  const _easycom_uni_popup2 = common_vendor.resolveComponent("uni-popup");
  const _easycom_uni_popup_message2 = common_vendor.resolveComponent("uni-popup-message");
  (_easycom_uni_file_picker2 + _easycom_uni_popup2 + _easycom_uni_popup_message2)();
}
const _easycom_uni_file_picker = () => "../../../uni_modules/uni-file-picker/components/uni-file-picker/uni-file-picker.js";
const _easycom_uni_popup = () => "../../../uni_modules/uni-popup/components/uni-popup/uni-popup.js";
const _easycom_uni_popup_message = () => "../../../uni_modules/uni-popup/components/uni-popup-message/uni-popup-message.js";
if (!Math) {
  (_easycom_uni_file_picker + _easycom_uni_popup + _easycom_uni_popup_message)();
}
function _sfc_render(_ctx, _cache, $props, $setup, $data, $options) {
  return common_vendor.e({
    a: common_vendor.sr("imgPicker", "013cc636-0"),
    b: common_vendor.j({
      "delete": common_vendor.o($options.delImgs),
      "select": common_vendor.o($options.uploadImgToNet)
    }),
    c: common_vendor.p({
      value: $data.files,
      ["del-icon"]: true,
      limit: "1",
      fileMediatype: "image",
      ["auto-upload"]: false,
      ["image-styles"]: $data.imageStyles
    }),
    d: common_vendor.n($data.rightName != "" ? "v-select" : ""),
    e: $data.rightName,
    f: common_vendor.o((...args) => $options.inputRightName && $options.inputRightName(...args)),
    g: $data.rightName.length > 0
  }, $data.rightName.length > 0 ? {
    h: common_vendor.o((...args) => $options.doClearRightName && $options.doClearRightName(...args))
  } : {}, {
    i: $data.selRightType.length <= 0
  }, $data.selRightType.length <= 0 ? {} : {
    j: common_vendor.f($data.selRightType, (item, index, i0) => {
      return {
        a: index,
        b: common_vendor.t(item.dataName)
      };
    })
  }, {
    k: common_vendor.o((...args) => $options.onShowRightType && $options.onShowRightType(...args)),
    l: $data.selRightType.length > 0
  }, $data.selRightType.length > 0 ? {
    m: common_vendor.o((...args) => $options.clearRightType && $options.clearRightType(...args))
  } : {}, {
    n: $data.selRightType.length <= 0
  }, $data.selRightType.length <= 0 ? {} : {}, {
    o: common_vendor.n($data.rightPrice != 0 ? "v-select" : ""),
    p: $data.rightPrice,
    q: common_vendor.o((...args) => $options.inputRightPrice && $options.inputRightPrice(...args)),
    r: $data.rightPrice != 0
  }, $data.rightPrice != 0 ? {
    s: common_vendor.o((...args) => $options.doClearPrice && $options.doClearPrice(...args))
  } : {}, {
    t: common_vendor.t($data.rightStopDate != "" ? $data.rightStopDate : "请选择截止售卖日期"),
    v: common_vendor.n($data.rightStopDate == "" ? "value-hint" : ""),
    w: $data.rightStopDate,
    x: $data.curStartDate,
    y: common_vendor.o((...args) => $options.bindDateChange && $options.bindDateChange(...args)),
    z: $data.rightStopDate != ""
  }, $data.rightStopDate != "" ? {
    A: common_vendor.o((...args) => $options.clearTime && $options.clearTime(...args))
  } : {}, {
    B: $data.rightStopDate == ""
  }, $data.rightStopDate == "" ? {} : {}, {
    C: common_vendor.t($data.selPersonType != null ? $data.selPersonType.dataName : "请选择类别"),
    D: common_vendor.n($data.selPersonType == null ? "value-hint" : ""),
    E: $data.personType,
    F: common_vendor.o((...args) => $options.bindChangePersonType && $options.bindChangePersonType(...args)),
    G: $data.selPersonType != null
  }, $data.selPersonType != null ? {
    H: common_vendor.o((...args) => $options.clearPersonType && $options.clearPersonType(...args))
  } : {}, {
    I: $data.selPersonType == null
  }, $data.selPersonType == null ? {} : {}, {
    J: common_vendor.n($data.orgName != "" ? "v-select" : ""),
    K: $data.orgName,
    L: common_vendor.o((...args) => $options.inputOrgName && $options.inputOrgName(...args)),
    M: common_vendor.t($data.selArea != null && $data.selCity != null ? $data.selArea.areaName + "/" + $data.selCity.areaName : "请选择所在省市"),
    N: common_vendor.o((...args) => $options.onShowArea && $options.onShowArea(...args)),
    O: common_vendor.n($data.selArea == null ? "value-hint" : ""),
    P: $data.selArea != null
  }, $data.selArea != null ? {
    Q: common_vendor.o((...args) => $options.clearArea && $options.clearArea(...args))
  } : {}, {
    R: $data.selArea == null
  }, $data.selArea == null ? {} : {}, {
    S: common_vendor.n($data.orgPhone != "" ? "v-select" : ""),
    T: $data.orgPhone,
    U: common_vendor.o((...args) => $options.inputOrgPhone && $options.inputOrgPhone(...args)),
    V: $data.orgPhone.length > 0
  }, $data.orgPhone.length > 0 ? {
    W: common_vendor.o((...args) => $options.doClearPhone && $options.doClearPhone(...args))
  } : {}, {
    X: common_vendor.t($data.selCreType != null ? $data.selCreType.dataName : "请选择证件类型"),
    Y: common_vendor.n($data.selCreType == null ? "value-hint" : ""),
    Z: $data.creType,
    aa: common_vendor.o((...args) => $options.bindChangeCreType && $options.bindChangeCreType(...args)),
    ab: $data.selCreType != null
  }, $data.selCreType != null ? {
    ac: common_vendor.o((...args) => $options.clearCreType && $options.clearCreType(...args))
  } : {}, {
    ad: $data.selCreType == null
  }, $data.selCreType == null ? {} : {}, {
    ae: common_vendor.n($data.cardNumber != "" ? "v-select" : ""),
    af: $data.cardNumber,
    ag: common_vendor.o((...args) => $options.inputCardNumber && $options.inputCardNumber(...args)),
    ah: common_vendor.o((...args) => $options.doSave && $options.doSave(...args)),
    ai: common_vendor.o((...args) => $options.closeDialog && $options.closeDialog(...args)),
    aj: common_vendor.f($data.rightType, (item, index, i0) => {
      return {
        a: index,
        b: common_vendor.t(item.dataName),
        c: item,
        d: common_vendor.n(item.checked ? "type-select" : "type-normal")
      };
    }),
    ak: common_vendor.o((...args) => $options.bindChangeRightType && $options.bindChangeRightType(...args)),
    al: common_vendor.o((...args) => $options.confirmSelType && $options.confirmSelType(...args)),
    am: common_vendor.sr("typeDialog", "013cc636-1"),
    an: common_vendor.p({
      type: "bottom",
      ["background-color"]: "#fff",
      ["border-radius"]: "15rpx 15rpx 0rpx 0rpx"
    }),
    ao: common_vendor.o((...args) => $options.closeDialog && $options.closeDialog(...args)),
    ap: common_vendor.f($data.areaList, (item, index, i0) => {
      return {
        a: index,
        b: common_vendor.t(item.areaName)
      };
    }),
    aq: common_vendor.f($data.cityList, (item, index, i0) => {
      return {
        a: index,
        b: common_vendor.t(item.areaName)
      };
    }),
    ar: common_vendor.o((...args) => $options.areaChange && $options.areaChange(...args)),
    as: common_vendor.o((...args) => $options.confirmSelType && $options.confirmSelType(...args)),
    at: common_vendor.sr("areaDialog", "013cc636-2"),
    av: common_vendor.p({
      type: "bottom",
      ["background-color"]: "#fff",
      ["border-radius"]: "15rpx 15rpx 0rpx 0rpx"
    }),
    aw: common_vendor.p({
      duration: 2e3,
      type: $data.msgType,
      message: $data.msgHint
    }),
    ax: common_vendor.sr("msg", "013cc636-3"),
    ay: common_vendor.p({
      type: "message"
    })
  });
}
const MiniProgramPage = /* @__PURE__ */ common_vendor._export_sfc(_sfc_main, [["render", _sfc_render], ["__scopeId", "data-v-013cc636"]]);
swan.createPage(MiniProgramPage);
//# sourceMappingURL=../../../../.sourcemap/mp-baidu/pages/shop/publishGoods/publishGoods.js.map
